function y = NoiseWhiteG_Optical(NoisePowerDensity)
%
% Usage: y = NoiseWhiteG_Optical(NoisePowerDensity)
%
% Purpose = This function simulates a Gaussian-distributed optical white noise source.
%
%  Input = Not required.
%  Output(y) = Optical noise signal (Size = 1 by DataLength) with power
%           spectral density = NoisePowerDensity from -fs/2 to +fs/2 
%
% ==== Physical Parameters ========
% NoisePowerDensity [W/Hz]
%
% (global variables) DataLength SampleRate t_range
%
% Note1) Single Polarization 
% Note2) Total output(noise) power = (NoisePowerDensity x SampleRate)
%
%------------------------------------------------------------
% $ Revision: 1.1 $ Date: 2011/02/22 by Jong-Hyung Lee  
%------------------------------------------------------------
%
%=====================================================================================
global SampleRate DataLength t_range

%single polarization

E_ase_r =sqrt(0.5*NoisePowerDensity*SampleRate)*randn(1,DataLength);%real component
E_ase_i =sqrt(0.5*NoisePowerDensity*SampleRate)*randn(1,DataLength);%imaginary component

% Generated noise,y, will have an approximate power ~ 'NoisePowerDensity*SampleRate'
% The noise power can be checked by PowerMeter

y = (E_ase_r + 1i*E_ase_i).*exp(1i*2*pi.*t_range) ; % Complex Gaussian Process

