function y = WDM_DeMux_Trapezoid(Optical_input,FlatTop_BW,CutoffMagnitude,CutoffBandwidth,IL)  
%
% Usage: y = WDM_DeMux_Trapezoid(Optical_input,FlatTop_BW,CutoffMagnitude,CutoffBandwidth,IL)
%
% Purpose = This module represents a DeMux with Trapezoid optical filters.
%
% Input Signal(Optical_input) = (Composite) Optical Signal (size = [1 x DataLength])
% Output Signal(y) = Demuxed (filtered & sorted) Optical Signal (size = [ChannelNumber x DataLength])
%
% ==== Physical Parameters ===== 
%   FlatTop_BW = Flat Top bandwidth of the filter [Hz]
%              = BitRate (default)
%   CutoffMagnitude = Attenuation at the cutoff bandwidth of the filter [dB]
%                   = 10 (default)
%   CutoffBandwidth = Cutoff bandwidth of the filter [Hz]
%                   = 10*BitRate (default)
%   IL  = insertion loss [dB]
%       = 3  (default) 
%
% Note1) Output size = FilterNumber by DataLength
% Note2) All the filter characteristicas (shape, bandwidth) are assumed equal.
% Note3) Filter spacing is uniform.
%
%----------------------------------------------------------
% $ Revision: 1.1 $ Date: 2011/02/22 by Jong-Hyung Lee
%=================================================================================================
global ChannelNumber ChannelSpacing BitRate

if nargin<5,
   IL = 3;% [dB]
end
if nargin <4
    CutoffBandwidth=10*BitRate;   
end    
if nargin<3,
    CutoffMagnitude = 10;%[dB]
end
if nargin<2,
   FlatTop_BW = BitRate;
end

AfterIL = Attenuator(Optical_input,IL);

FilterNumber = ChannelNumber;
FilterSpacing = ChannelSpacing;

if FilterNumber == 1
   
    y = OpticalFilter_Trapezoid(AfterIL,0,FlatTop_BW,CutoffMagnitude,CutoffBandwidth);
        
else
   
    for k = 1:FilterNumber
              
          FilterCenter(k) = FilterSpacing*(k - (FilterNumber+1)/2);
          y(k,:) = OpticalFilter_Trapezoid(AfterIL,FilterCenter(k),FlatTop_BW,CutoffMagnitude,CutoffBandwidth);%                
       
     end  
     
 end    
    
